=== modified file 'commit.py'
--- commit.py	2007-10-12 17:26:02 +0000
+++ commit.py	2007-10-12 18:10:24 +0000
@@ -177,8 +177,10 @@
         #  changed_content, versioned, parent, name, kind,
         #  executable)
 
+        all_enabled = (self._selected is None)
         # The first entry is always the 'whole tree'
-        store.append([None, None, True, 'All Files', '', ''])
+        all_iter = store.append([None, None, all_enabled, 'All Files', '', ''])
+        initial_cursor = store.get_path(all_iter)
         # should we pass specific_files?
         self._wt.lock_read()
         self._basis_tree.lock_read()
@@ -186,9 +188,20 @@
             from diff import _iter_changes_to_status
             for (file_id, real_path, change_type, display_path
                 ) in _iter_changes_to_status(self._basis_tree, self._wt):
-                store.append([file_id, real_path.encode('UTF-8'),
-                              True, display_path.encode('UTF-8'),
-                              change_type, ''])
+                if self._selected and real_path != self._selected:
+                    enabled = False
+                else:
+                    enabled = True
+                item_iter = store.append([
+                    file_id,
+                    real_path.encode('UTF-8'),
+                    enabled,
+                    display_path.encode('UTF-8'),
+                    change_type,
+                    '', # Initial comment
+                    ])
+                if self._selected and enabled:
+                    initial_cursor = store.get_path(item_iter)
         finally:
             self._basis_tree.unlock()
             self._wt.unlock()
@@ -198,7 +211,7 @@
         # This sets the cursor, which causes the expander to close, which
         # causes the _file_message_text_view to never get realized. So we have
         # to give it a little kick, or it warns when we try to grab the focus
-        self._treeview_files.set_cursor(0)
+        self._treeview_files.set_cursor(initial_cursor)
 
         def _realize_file_message_tree_view(*args):
             self._file_message_text_view.realize()

=== modified file 'olive/__init__.py'
--- olive/__init__.py	2007-09-15 14:42:19 +0000
+++ olive/__init__.py	2007-10-12 18:10:24 +0000
@@ -502,7 +502,14 @@
     @show_bzr_error
     def on_menuitem_branch_commit_activate(self, widget):
         """ Branch/Commit... menu handler. """
-        commit = CommitDialog(self.wt, self.wtpath, self.notbranch, self.get_selected_right(), self.window)
+#     def __init__(self, wt, wtpath, notbranch, selected=None, parent=None):
+        selected = self.get_selected_right()
+        if selected:
+            selected = os.path.join(self.wtpath, selected)
+        commit = CommitDialog(wt=self.wt,
+                              parent=self.window,
+                              selected=selected,
+                             )
         response = commit.run()
         if response != gtk.RESPONSE_NONE:
             commit.hide()

=== modified file 'olive/menu.py'
--- olive/menu.py	2007-09-17 21:14:04 +0000
+++ olive/menu.py	2007-10-12 18:10:24 +0000
@@ -288,7 +288,11 @@
         except NotBranchError, e:
             path = e.path
         
-        commit = CommitDialog(wt, path, not branch, self.selected)
+        if self.selected:
+            selected = os.path.join(path, self.selected)
+        else:
+            selected = None
+        commit = CommitDialog(wt=wt, selected=selected, parent=None)
         response = commit.run()
         if response != gtk.RESPONSE_NONE:
             commit.hide()

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2007-10-09 23:36:13 +0000
+++ tests/test_commit.py	2007-10-12 18:10:24 +0000
@@ -369,6 +369,23 @@
                           ('a-id', 'a', True, 'a', 'removed'),
                           ('b-id', 'b', True, 'b/', 'removed'),
                          ], values)
+        # All Files should be selected
+        self.assertEqual(((0,), None), dlg._treeview_files.get_cursor())
+
+    def test_filelist_with_selected(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/a', 'tree/b/'])
+        tree.add(['a', 'b'], ['a-id', 'b-id'])
+
+        dlg = commit.CommitDialog(tree, selected='a')
+        values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
+        self.assertEqual([(None, None, False, 'All Files', ''),
+                          ('a-id', 'a', True, 'a', 'added'),
+                          ('b-id', 'b', False, 'b/', 'added'),
+                         ], values)
+        # This file should also be selected in the file list, rather than the
+        # 'All Files' selection
+        self.assertEqual(((1,), None), dlg._treeview_files.get_cursor())
 
     def test_diff_view(self):
         tree = self.make_branch_and_tree('tree')

